@@ -3,23 +3,23 @@
 #' @description  Generates a formatted report of the analysis 
 #'    and saves it to a text or an Excel file
 #' 
-#' @param dataset The dataset object to be analyzed (\emph{not the file name}), see \code{Dataset} 
-#'    in \code{\link{RJafroc-package}}.
+#' @param dataset The dataset object to be analyzed (\emph{not the file name}), 
+#' see \code{Dataset} in \code{\link{RJafroc-package}}.
 #'    
 #' @param dataDescription A short string describing the dataset, 
 #'    the default is "MyDataDescription: ";
 #'    it is inserted, for reference, in the output file.
 #'    
-#' @param ReportFileBaseName The file bse name (sans extension) for the desired report; 
-#'    the default is NULL, in which case the system generates a temporary text file, whose 
-#'    name will be displayed. If an Excel file is desired, the extension should be  
-#'    ".xlsx"; if a text file output is desired, the extension should be 
-#'    ".txt".  
+#' @param ReportFileBaseName The file base name (sans the extension) for the 
+#'    desired report; the default is NULL, in which case the system generates 
+#'    a temporary text file, whose name is displayed.  
 #'    
-#' @param ReportFileExt The file extension determines the type of output. \code{txt}, the default, for 
+#' @param ReportFileExt The report file extension determines the type of output. 
+#'    \code{txt}, the default, for 
 #'    a text file, \code{xlsx} for an Excel file.
 #'    
-#' @param method The significance testing method, \code{"ORH"} or (the default) \code{"DBMH"}.
+#' @param method The significance testing method, \code{"ORH"} or 
+#'    (the default) \code{"DBMH"}.
 #' 
 #' @param FOM The figure of merit; see \code{\link{StSignificanceTesting}}.
 #' 
@@ -28,10 +28,10 @@
 #' @param covEstMethod See \code{\link{StSignificanceTesting}}; only needed 
 #'     for method = \code{"ORH"}; the default is "Jackknife".
 #' 
-#' @param nBoots See \code{\link{StSignificanceTesting}}; only needed for \code{"ORH"} analysis;
-#'     the default is 200.
+#' @param nBoots See \code{\link{StSignificanceTesting}}; only needed for 
+#'    \code{"ORH"} analysis; the default is 200.
 #' 
-#' @param renumber A logical variable: if \code{TRUE}, consecutive integers 
+#' @param sequentialNames A logical variable: if \code{TRUE}, consecutive integers 
 #'    (staring from 1) will be used as the treatment and reader IDs in the 
 #'    output report. Otherwise, treatment and reader IDs in the original data 
 #'    file will be used. This option may be needed for aesthetics. The default
@@ -40,8 +40,8 @@
 #' @param overWrite A \code{logical} variable: if \code{FALSE}, a warning will 
 #'    be issued if the report file already exists and the program will wait 
 #'    until the user inputs "y" or "n" to determine whether to overwrite the 
-#'    existing file. If \code{TRUE}, the existing file will be silently overwritten. The
-#'    default is \code{FALSE}.
+#'    existing file. If \code{TRUE}, the existing file will be silently overwritten. 
+#'    The default is \code{FALSE}.
 #' 
 #' 
 #' @details
@@ -54,9 +54,10 @@
 #' @examples
 #' 
 #' \donttest{
-#' UtilOutputReport(dataset03) # text output is created in a temporary file
-#'
-#' UtilOutputReport(dataset03, ReportFileExt = "xlsx") # Excel output is created in a temporary file
+#'  # text output is created in a temporary file
+#' UtilOutputReport(dataset03, FOM = "Wilcoxon")
+#' # Excel output is created in a temporary file
+#' UtilOutputReport(dataset03, FOM = "Wilcoxon", ReportFileExt = "xlsx") 
 #'
 #' }
 #'        
@@ -67,9 +68,9 @@
 
 UtilOutputReport <- function(dataset, dataDescription = "MyDataDescription: ", 
                              ReportFileBaseName = NULL, ReportFileExt = "txt", 
-                             method = "DBMH", FOM = "Wilcoxon", alpha = 0.05, 
+                             method = "DBMH", FOM, alpha = 0.05, 
                              covEstMethod = "Jackknife", nBoots = 200, 
-                             renumber = FALSE, overWrite = FALSE) {
+                             sequentialNames = FALSE, overWrite = FALSE) {
   
   if (!isValidDataset(dataset)) {
     stop("Must specify a valid dataset object.")
@@ -79,7 +80,7 @@ UtilOutputReport <- function(dataset, dataDescription = "MyDataDescription: ",
     stop("Inconsistent dataset - FOM combination")
   }
   
-  if (renumber){
+  if (sequentialNames){
     dataset$modalityID <- 1:length(dataset$modalityID)
     dataset$readerID <- 1:length(dataset$readerID)
   }
@@ -112,10 +113,10 @@ UtilOutputReport <- function(dataset, dataDescription = "MyDataDescription: ",
   
   if (method == "DBMH") {
     methodTxt <- paste0("DBM-MRMC-HILLIS SIGNIFICANCE TESTING: ", dataDescription)
-    sigTestResult <- StSignificanceTesting(dataset, FOM, alpha, method)
+      sigTestResult <- StSignificanceTesting(dataset, FOM, FPFValue = 0.2, alpha, method)
   } else if (method == "ORH") {
     methodTxt <- paste0("OBUCHOWSKI-ROCKETTE-HILLIS SIGNIFICANCE TESTING: ", dataDescription)
-    sigTestResult <- StSignificanceTesting(dataset, FOM, alpha, method, covEstMethod, nBoots)
+    sigTestResult <- StSignificanceTesting(dataset, FOM, FPFValue = 0.2, alpha, method, covEstMethod, nBoots)
   } else {
     errMsg <- paste0(method, " is not a valid analysis method.")
     stop(errMsg)
@@ -435,52 +436,52 @@ OutputTextFile <- function(dataset,
             " ----------  ------  ---------------  -------  -------"), 
           ReportFileName, append = TRUE)
     if (method == "DBMH") {
-      if (sigTestResult$pRRRC >= smallestDispalyedPval) {
+      if (sigTestResult$FTestStatsRRRC$pRRRC >= smallestDispalyedPval) {
         write(sprintf(" Treatment   %6d  %15.8f  %7.2f  %7.4f", 
                       I - 1, 
                       sigTestResult$anovaY[1, 4], 
-                      sigTestResult$fRRRC, 
-                      sigTestResult$pRRRC), 
+                      sigTestResult$FTestStatsRRRC$fRRRC, 
+                      sigTestResult$FTestStatsRRRC$pRRRC), 
               ReportFileName, append = TRUE)
       } else {
         write(sprintf(" Treatment   %6d  %15.8f  %7.2f  <%6.4f", 
                       I - 1, sigTestResult$anovaY[1, 4], 
-                      sigTestResult$fRRRC, 
+                      sigTestResult$FTestStatsRRRC$fRRRC, 
                       smallestDispalyedPval), 
               ReportFileName, append = TRUE)
       }
       write(sprintf(" Error       %6.2f  %15.8f", 
-                    sigTestResult$ddfRRRC, 
+                    sigTestResult$FTestStatsRRRC$ddfRRRC, 
                     sigTestResult$anovaY[4, 4] + max(sigTestResult$anovaY[5, 4] - sigTestResult$anovaY[7, 4])), 
             ReportFileName, append = TRUE)
       write(" Error term: MS(TR) + max[MS(TC) - MS(TRC), 0]\n", 
             ReportFileName, append = TRUE)
     } else {
-      if (sigTestResult$pRRRC >= smallestDispalyedPval) {
+      if (sigTestResult$FTestStatsRRRC$ddfRRRC >= smallestDispalyedPval) {
         write(sprintf(" Treatment   %6d  %15.8f  %7.2f  %7.4f", 
-                      I - 1, sigTestResult$msT, sigTestResult$fRRRC, sigTestResult$pRRRC), 
+                      I - 1, sigTestResult$msT, sigTestResult$FTestStatsRRRC$fRRRC, sigTestResult$FTestStatsRRRC$ddfRRRC), 
               ReportFileName, append = TRUE)
       } else {
         write(sprintf(" Treatment   %6d  %15.8f  %7.2f  <%6.4f", 
-                      I - 1, sigTestResult$msT, sigTestResult$fRRRC, smallestDispalyedPval), 
+                      I - 1, sigTestResult$msT, sigTestResult$FTestStatsRRRC$fRRRC, smallestDispalyedPval), 
               ReportFileName, append = TRUE)
       }
       write(sprintf(" Error       %6.2f  %15.8f", 
-                    sigTestResult$ddfRRRC, 
+                    sigTestResult$FTestStatsRRRC$ddfRRRC, 
                     sigTestResult$msTR + max(J * (sigTestResult$varComp[3, 2] - sigTestResult$varComp[4, 2]), 0)), 
             ReportFileName, append = TRUE)
       write(" Error term: MS(TR) + J * max[Cov2 - Cov3, 0]\n", 
             ReportFileName, append = TRUE)
     }
     
-    if (sigTestResult$pRRRC < alpha) {
+    if (sigTestResult$FTestStatsRRRC$ddfRRRC < alpha) {
       write(sprintf(" Conclusion: The %s FOMs of treatments are not equal,\n             F(%d,%3.2f) = %3.2f, p = %6.4f.\n\n", 
-                    FOM, I - 1, sigTestResult$ddfRRRC, sigTestResult$fRRRC, sigTestResult$pRRRC), 
+                    FOM, I - 1, sigTestResult$FTestStatsRRRC$ddfRRRC, sigTestResult$FTestStatsRRRC$fRRRC, sigTestResult$FTestStatsRRRC$ddfRRRC), 
             ReportFileName, 
             append = TRUE)
     } else {
       write(sprintf(" Conclusion: The %s FOMs of treatments are not significantly different,\n             F(%d,%3.2f) = %3.2f, p = %6.4f.\n\n", 
-                    FOM, I - 1, sigTestResult$ddfRRRC, sigTestResult$fRRRC, sigTestResult$pRRRC), 
+                    FOM, I - 1, sigTestResult$FTestStatsRRRC$ddfRRRC, sigTestResult$FTestStatsRRRC$fRRRC, sigTestResult$FTestStatsRRRC$ddfRRRC), 
             ReportFileName, append = TRUE)
     }
     write(sprintf("    b) %d%% confidence intervals for treatment differences\n", ciPercent), 
@@ -557,71 +558,71 @@ OutputTextFile <- function(dataset,
           " ----------  ------  ---------------  -------  -------"), 
         ReportFileName, append = TRUE)
   if (method == "DBMH") {
-    if (sigTestResult$pFRRC >= smallestDispalyedPval) {
+    if (sigTestResult$FTestStatsFRRC$ddfFRRC >= smallestDispalyedPval) {
       write(sprintf(" Treatment   %6d  %15.8f  %7.2f  %7.4f", 
                     I - 1, 
                     sigTestResult$anovaY[1, 4], 
-                    sigTestResult$fFRRC, 
-                    sigTestResult$pFRRC), 
+                    sigTestResult$FTestStatsFRRC$fFRRC, 
+                    sigTestResult$FTestStatsFRRC$ddfFRRC), 
             ReportFileName, append = TRUE)
     } else {
       write(sprintf(" Treatment   %6d  %15.8f  %7.2f  <%6.4f", 
                     I - 1, 
                     sigTestResult$anovaY[1, 4], 
-                    sigTestResult$fFRRC, 
+                    sigTestResult$FTestStatsFRRC$fFRRC, 
                     smallestDispalyedPval), 
             ReportFileName, append = TRUE)
     }
     write(sprintf(" Error       %6.2f  %15.8f", 
-                  sigTestResult$ddfFRRC, sigTestResult$anovaY[5, 4]), 
+                  sigTestResult$FTestStatsFRRC$ddfFRRC, sigTestResult$anovaY[5, 4]), 
           ReportFileName, append = TRUE)
     write("  Error term: MS(TC)\n", ReportFileName, append = TRUE)
   } else {
-    if (sigTestResult$pFRRC >= smallestDispalyedPval) {
+    if (sigTestResult$FTestStatsFRRC$ddfFRRC >= smallestDispalyedPval) {
       write(sprintf(" Treatment   %6d  %15.8f  %7.2f  %7.4f", 
                     I - 1, 
                     sigTestResult$msT, 
-                    sigTestResult$fFRRC, 
-                    sigTestResult$pFRRC), 
+                    sigTestResult$FTestStatsFRRC$fFRRC, 
+                    sigTestResult$FTestStatsFRRC$ddfFRRC), 
             ReportFileName, append = TRUE)
     } else {
       write(sprintf(" Treatment   %6d  %15.8f  %7.2f  <%6.4f", 
                     I - 1, 
                     sigTestResult$msT, 
-                    sigTestResult$fFRRC, 
+                    sigTestResult$FTestStatsFRRC$fFRRC, 
                     smallestDispalyedPval), 
             ReportFileName, append = TRUE)
     }
     if (J > 1) {
       write(sprintf(" Error       %6.2f  %15.8f", 
-                    sigTestResult$ddfFRRC, 
+                    sigTestResult$FTestStatsFRRC$ddfFRRC, 
                     (sigTestResult$varComp[1, 2] - sigTestResult$varComp[2, 2] + (J - 1) * (sigTestResult$varComp[3, 2] - sigTestResult$varComp[4, 2]))), 
             ReportFileName, append = TRUE)
       write(" Error term: Var - Cov1 + (J - 1) * ( Cov2 - Cov3 )\n", 
             ReportFileName, append = TRUE)
     } else {
       write(sprintf(" Error       %6.2f  %15.8f", 
-                    sigTestResult$ddfFRRC, (sigTestResult$varComp[1, 2] - sigTestResult$varComp[2, 2])), 
+                    sigTestResult$FTestStatsFRRC$ddfFRRC, (sigTestResult$varComp[1, 2] - sigTestResult$varComp[2, 2])), 
             ReportFileName, append = TRUE)
       write(" Error term: Var - Cov1\n", 
             ReportFileName, append = TRUE)
     }
   }
   
-  if (sigTestResult$pFRRC < alpha) {
+  if (sigTestResult$FTestStatsFRRC$ddfFRRC < alpha) {
     write(sprintf(" Conclusion: The %s FOMs of treatments are not equal,\n             F(%d,%3.2f) = %3.2f, p = %6.4f.\n\n", 
                   FOM, I - 1, 
-                  sigTestResult$ddfFRRC, 
-                  sigTestResult$fFRRC, 
-                  sigTestResult$pFRRC), 
+                  sigTestResult$FTestStatsFRRC$ddfFRRC, 
+                  sigTestResult$FTestStatsFRRC$fFRRC, 
+                  sigTestResult$FTestStatsFRRC$ddfFRRC), 
           ReportFileName, append = TRUE)
   } else {
     write(sprintf(" Conclusion: The %s FOMs of treatments are not significantly different,\n             F(%d,%3.2f) = %3.2f, p = %6.4f.\n\n", 
                   FOM, 
                   I - 1, 
-                  sigTestResult$ddfFRRC, 
-                  sigTestResult$fFRRC, 
-                  sigTestResult$pFRRC), 
+                  sigTestResult$FTestStatsFRRC$ddfFRRC, 
+                  sigTestResult$FTestStatsFRRC$fFRRC, 
+                  sigTestResult$FTestStatsFRRC$ddfFRRC), 
           ReportFileName, append = TRUE)
   }
   
@@ -796,63 +797,63 @@ OutputTextFile <- function(dataset,
             " ----------  ------  ---------------  -------  -------"), 
           ReportFileName, append = TRUE)
     if (method == "DBMH") {
-      if (sigTestResult$pRRFC >= smallestDispalyedPval) {
+      if (sigTestResult$FTestStatsRRFC$pRRFC >= smallestDispalyedPval) {
         write(sprintf(" Treatment   %6d  %15.8f  %7.2f  %7.4f", 
                       I - 1, 
                       sigTestResult$anovaY[1, 4], 
-                      sigTestResult$fRRFC, 
-                      sigTestResult$pRRFC), 
+                      sigTestResult$FTestStatsRRFC$fRRFC, 
+                      sigTestResult$FTestStatsRRFC$pRRFC), 
               ReportFileName, append = TRUE)
       } else {
         write(sprintf(" Treatment   %6d  %15.8f  %7.2f  <%6.4f", 
                       I - 1, 
                       sigTestResult$anovaY[1, 4], 
-                      sigTestResult$fRRFC, 
+                      sigTestResult$FTestStatsRRFC$fRRFC, 
                       smallestDispalyedPval), 
               ReportFileName, append = TRUE)
       }
       write(sprintf(" Error       %6.2f  %15.8f", 
-                    sigTestResult$ddfRRFC, 
+                    sigTestResult$FTestStatsRRFC$ddfRRFC, 
                     sigTestResult$anovaY[4, 4]), 
             ReportFileName, append = TRUE)
     } else {
-      if (sigTestResult$pRRFC >= smallestDispalyedPval) {
+      if (sigTestResult$FTestStatsRRFC$pRRFC >= smallestDispalyedPval) {
         write(sprintf(" Treatment   %6d  %15.8f  %7.2f  %7.4f", 
                       I - 1, 
                       sigTestResult$msT, 
-                      sigTestResult$fRRFC, 
-                      sigTestResult$pRRFC), 
+                      sigTestResult$FTestStatsRRFC$fRRFC, 
+                      sigTestResult$FTestStatsRRFC$pRRFC), 
               ReportFileName, append = TRUE)
       } else {
         write(sprintf(" Treatment   %6d  %15.8f  %7.2f  <%6.4f", 
                       I - 1, 
                       sigTestResult$msT, 
-                      sigTestResult$fRRFC, 
+                      sigTestResult$FTestStatsRRFC$fRRFC, 
                       smallestDispalyedPval), 
               ReportFileName, append = TRUE)
       }
       write(sprintf(" Error       %6.2f  %15.8f", 
-                    sigTestResult$ddfRRFC, 
+                    sigTestResult$FTestStatsRRFC$ddfRRFC, 
                     sigTestResult$msTR), 
             ReportFileName, append = TRUE)
     }
     write(" Error term: MS(TR)\n", 
           ReportFileName, append = TRUE)
     
-    if (sigTestResult$pRRFC < alpha) {
+    if (sigTestResult$FTestStatsRRFC$pRRFC < alpha) {
       write(sprintf(" Conclusion: The %s FOMs of treatments are not equal,\n             F(%d,%3.2f) = %3.2f, p = %6.4f.\n\n", 
                     FOM, 
                     I - 1, 
-                    sigTestResult$ddfRRFC, 
-                    sigTestResult$fRRFC, 
-                    sigTestResult$pRRFC), ReportFileName, append = TRUE)
+                    sigTestResult$FTestStatsRRFC$ddfRRFC, 
+                    sigTestResult$FTestStatsRRFC$fRRFC, 
+                    sigTestResult$FTestStatsRRFC$pRRFC), ReportFileName, append = TRUE)
     } else {
       write(sprintf(" Conclusion: The %s FOMs of treatments are not significantly different,\n             F(%d,%3.2f) = %3.2f, p = %6.4f.\n\n", 
                     FOM, 
                     I - 1, 
-                    sigTestResult$ddfRRFC, 
-                    sigTestResult$fRRFC, 
-                    sigTestResult$pRRFC), 
+                    sigTestResult$FTestStatsRRFC$ddfRRFC, 
+                    sigTestResult$FTestStatsRRFC$fRRFC, 
+                    sigTestResult$FTestStatsRRFC$pRRFC), 
             ReportFileName, append = TRUE)
     }
     write(sprintf("    b) %d%% confidence intervals for treatment differences\n", ciPercent), 
@@ -1023,7 +1024,7 @@ OutputExcelFile <- function(dataset,
   addWorksheet(wb, "RRRC")
   setColWidths(wb, sheet = "RRRC", cols = 1:8, widths = "auto", ignoreMergedCells = TRUE)
   setColWidths(wb, sheet = "RRRC", cols = 1, widths = 10)
-  testTable <- data.frame(f = sigTestResult$fRRRC, ddf = sigTestResult$ddfRRRC, p = sigTestResult$pRRRC)
+  testTable <- data.frame(f = sigTestResult$FTestStatsRRRC$fRRRC, ddf = sigTestResult$FTestStatsRRRC$ddfRRRC, p = sigTestResult$FTestStatsRRRC$ddfRRRC)
   names(testTable) <- c("F statistic", "ddf", "P-value")
   writeData(wb, sheet = "RRRC", x = testTable, rowNames = FALSE, colNames = TRUE)
   
@@ -1032,14 +1033,14 @@ OutputExcelFile <- function(dataset,
     if (i == I) 
       break
     for (ip in (i + 1):I) {
-      diffTRName <- c(diffTRName, paste(modalityID[i], modalityID[ip], sep = " - "))
+      diffTRName <- c(diffTRName, paste(modalityID[i], modalityID[ip], sep = "-"))
     }
   }
   
   diffTable <- sigTestResult$ciDiffTrtRRRC
   diffTable[ , 1] <- diffTRName
   diffTable[ , 2] <- as.numeric(diffTable[ , 2])
-  names(diffTable) <- c("Difference",	"Estimate",	"StdErr",	"DF",	"t",	"Pr > t",	"Lower",	"Upper")
+  names(diffTable) <- c("Difference",	"Estimate",	"StdErr",	"DF",	"t",	"Pr>t",	"Lower",	"Upper")
   writeData(wb, sheet = "RRRC", 
             startRow = 5, 
             x = diffTable, 
@@ -1071,7 +1072,7 @@ OutputExcelFile <- function(dataset,
   addWorksheet(wb, "FRRC")
   setColWidths(wb, sheet = "FRRC", cols = 1:9, widths = "auto", ignoreMergedCells = TRUE)
   setColWidths(wb, sheet = "FRRC", cols = 1, widths = 10)
-  testTable <- data.frame(f = sigTestResult$fFRRC, ddf = sigTestResult$ddfFRRC, p = sigTestResult$pFRRC)
+  testTable <- data.frame(f = sigTestResult$FTestStatsFRRC$fFRRC, ddf = sigTestResult$FTestStatsFRRC$ddfFRRC, p = sigTestResult$FTestStatsFRRC$ddfFRRC)
   if (method == "ORH"){
     testTable$ddf <- "Inf"
   }
@@ -1146,7 +1147,7 @@ OutputExcelFile <- function(dataset,
   addWorksheet(wb, "RRFC")
   setColWidths(wb, sheet = "RRFC", cols = 1:8, widths = "auto", ignoreMergedCells = TRUE)
   setColWidths(wb, sheet = "RRFC", cols = 1, widths = 10)
-  testTable <- data.frame(f = sigTestResult$fRRFC, ddf = sigTestResult$ddfRRFC, p = sigTestResult$pRRFC)
+  testTable <- data.frame(f = sigTestResult$FTestStatsRRFC$fRRFC, ddf = sigTestResult$FTestStatsRRFC$ddfRRFC, p = sigTestResult$FTestStatsRRFC$pRRFC)
   names(testTable) <- c("F statistic", "ddf", "P-value")
   writeData(wb, sheet = "RRFC", x = testTable, rowNames = FALSE, colNames = TRUE)
   
