@@ -34,11 +34,16 @@ NumericVector xROCVect(NumericVector zeta, double lambdaP){
 
 // [[Rcpp::export]]
 double yROC(double zeta, double mu, double lambdaP, double nuP, NumericMatrix lesDistr){
-  NumericVector fl = lesDistr(_, 1) / sum(lesDistr(_, 1));
+  NumericVector fl = lesDistr(_, 1) / sum(lesDistr(_, 1)); // unnecessary normalization to unit-sum weights, but OK
   double TPF = 0;
   
   for (int i = 0; i < lesDistr.nrow(); i++){
-    TPF = TPF + fl[i] * (1 - pow(1 - nuP/2 + nuP/2  * erfcpp( (zeta - mu) / sqrt(2.0) ) , lesDistr(i, 0)) * exp( (-lambdaP / 2) + 0.5 * lambdaP * erfcpp(zeta / sqrt(2.0))));
+    // lesDistr(i, 0) contains the nunber of lesions per case
+    // fl[i] is the fraction of cases with lesDistr(i, 0) lesions
+    // no changes made to code, just convincing myself that it is correct
+    TPF = TPF + fl[i] * (1 - 
+      pow(1 - nuP/2 + nuP/2  * erfcpp( (zeta - mu) / sqrt(2.0) ) , 
+          lesDistr(i, 0)) * exp( (-lambdaP / 2) + 0.5 * lambdaP * erfcpp(zeta / sqrt(2.0))));
   }
   return TPF;
 }
@@ -58,20 +63,22 @@ NumericVector yROCVect(NumericVector zeta, double mu, double lambdaP, double nuP
   return TPF;
 }
 
-// [[Rcpp::export]]
-NumericVector yROCVectNuP(double zeta, double mu, double lambdaP, NumericVector nuP, NumericMatrix lesDistr){
-  NumericVector fl = lesDistr(_, 1) / sum(lesDistr(_, 1));
-  int l = nuP.size();
-  NumericVector TPF(l);
-  
-  for (int il = 0; il < l; il ++){
-    for (int i = 0; i < lesDistr.nrow(); i++){
-      TPF[il] = TPF[il] + fl[i] * (1 - pow(1 - nuP[il]/2 + nuP[il]/2  * erfcpp( (zeta - mu) / sqrt(2.0) ) , lesDistr(i, 0)) * exp( (-lambdaP / 2) + 0.5 * lambdaP * erfcpp(zeta / sqrt(2.0))));
-    }
-  }
-  
-  return TPF;
-}
+
+
+// // [[Rcpp::export]]
+// NumericVector yROCVectNuP(double zeta, double mu, double lambdaP, NumericVector nuP, NumericMatrix lesDistr){
+//   NumericVector fl = lesDistr(_, 1) / sum(lesDistr(_, 1));
+//   int l = nuP.size();
+//   NumericVector TPF(l);
+//   
+//   for (int il = 0; il < l; il ++){
+//     for (int i = 0; i < lesDistr.nrow(); i++){
+//       TPF[il] = TPF[il] + fl[i] * (1 - pow(1 - nuP[il]/2 + nuP[il]/2  * erfcpp( (zeta - mu) / sqrt(2.0) ) , lesDistr(i, 0)) * exp( (-lambdaP / 2) + 0.5 * lambdaP * erfcpp(zeta / sqrt(2.0))));
+//     }
+//   }
+//   
+//   return TPF;
+// }
 
 // // [[Rcpp::export]]
 // double DiffAucSmMinusAucCbm(double mu, double lambdaP, double nuP, NumericMatrix lesDistr, double AUCCbm){
@@ -160,3 +167,70 @@ NumericVector intROC(NumericVector FPF, double mu, double lambdaP, double nuP, N
   // Rcpp::Rcout << "zeta is now " << zeta << std::endl;
   return yROCVect(zeta, mu, lambdaP, nuP, lesDistr);
 }
+
+
+// double factrl (const int n) {
+//   static NumericVector a(171);
+//   static bool init = true;
+//   if (init) {
+//     init = false;
+//     a[0] = 1;
+//     for (int i = 1; i <171; i++) a[i] = i*a[i-1];
+//   }
+//   if (n < 0 || n > 170) throw("factrl out of range");
+//   return a[n];
+// }
+// 
+// 
+// double BinCombFunction(int N, int n) {
+//   return factrl(N)/factrl(N-n)/factrl(n);
+// }
+// 
+// 
+// double dbinom(int lesLocalizations, int trialSize, double prob) {
+//   return BinCombFunction(trialSize, lesLocalizations) * 
+//     pow(prob, lesLocalizations)* pow(1-prob, trialSize - lesLocalizations);
+// }
+
+
+
+// // [[Rcpp::export]]
+// NumericVector ywAFROC (NumericVector zeta, double mu, double nuP,
+//                        NumericMatrix lesDistr, NumericMatrix lesWghtDistr){
+//   int len = zeta.size();
+//   NumericVector wLLF(len);
+//   NumericVector fl = lesDistr(_, 1) / sum(lesDistr(_, 1));
+//   for (int l1 = 0;l1 < len; l1++) {
+//     // wLLF[l1] = 0;
+//     for (int l = 0;l < lesDistr.nrow();l++) {
+//       int nLesPerCase = lesDistr(l, 0);
+//       double wLLFTmp = 0;
+//       for (int LL = 0; LL < nLesPerCase; LL++){
+//         wLLFTmp = wLLFTmp + lesWghtDistr(l, LL+1) * LL *
+//           dbinom(LL, nLesPerCase, nuP) * (1 - R::pnorm(zeta[l1] - mu, 0, 1, 1, 0));
+//       }
+//       wLLF[l1] = wLLF[l1] +  fl[l] * wLLFTmp;
+//     }
+//   }
+//   return wLLF;
+// }
+
+// [[Rcpp::export]]
+double ywAFROC (double zeta, double mu, double nuP,
+                NumericMatrix lesDistr, NumericMatrix lesWghtDistr){
+  NumericVector fl = lesDistr(_, 1) / sum(lesDistr(_, 1));
+  double wLLF = 0; 
+  for (int row = 0;row < lesDistr.nrow();row++) { 
+    int nLesPerCase = lesDistr(row, 0);
+    double wLLFrow = 0;
+    for (int col = 0; col < nLesPerCase; col++){
+      wLLFrow += lesWghtDistr(row, col+1) * (col+1) *
+        R::dbinom(double(col+1), double(nLesPerCase), nuP, 0) * (1 - R::pnorm(zeta - mu, 0, 1, 1, 0));
+// above line was tricky; note difference in col indexing from R code: lesWghtDistr[row, col+1] * col * dbinom(col, nLesPerCase, nuP) * (1 - pnorm(zeta - mu))
+// this is due to zero-based C indexing vs. 1 based r indexing
+    }
+    wLLF += fl[row] * wLLFrow;
+  }
+  return wLLF;
+}
+
